#ifndef QUOTING_H
#define QUOTING_H

typedef enum _quoting_t {
	QUOTE_ALL,
	QUOTE_NONE,
	QUOTE_MINIMAL,
	QUOTE_NUMERIC,
	QUOTE_ORIGINAL,
} quoting_t;

#endif // QUOTING_H
